# background-task

Background tasks management for HUEY queue.

## Install

```
pip install django-kcommunication
```

## Usage:

Add "kcommunication" and "kbackgroundtask" to app list:


```
INSTALLED_APPS = [
    "kcommunication",
    "kbackgroundtask"
]
```
